@@ -107,7 +107,10 @@ class Database:
                         df[col] = df[col].map(lambda x: round(x, 0))
                         df[col] = df[col].astype(int)
 
-                df = df[['date', 'time', 'open', 'high', 'low', 'close', 'volume']]
+                if 'T' in freq:
+                    df = df[['date', 'time', 'open', 'high', 'low', 'close', 'volume']]
+                else:
+                    df = df[['date', 'open', 'high', 'low', 'close', 'volume']]
 
             return df
     
@@ -236,7 +239,7 @@ class Database:
                     for temp_date in temp_date_list:
                         if datetime.datetime.strptime(str(temp_date),'%Y%m%d').weekday() < 5:
                             date_list.append(temp_date)
-
+                    
                     front_year_month = str(date_list[0])[2:6]
                     back_year_month = str(date_list[-1])[2:6]
                     front_expiry_date = int(expiry_date_dict[front_year_month].strftime('%Y%m%d'))
@@ -256,9 +259,11 @@ class Database:
     
                     if df.loc[0,'expiry_date'] == '20130530':
                         front_cut_off_date = 20130501
-
-                    df = df[(df['date'] > front_cut_off_date) | ((df['date'] == front_cut_off_date) & (df['time'] >= rolling_time))]
-                    df = df[(df['date'] < back_cut_off_date) | ((df['date'] == back_cut_off_date) & (df['time'] < rolling_time))]
+                    
+                    if back_cut_off_date != end_date:
+                        df = df[(df['date'] > front_cut_off_date) | ((df['date'] == front_cut_off_date) & (df['time'] >= rolling_time))]
+                        df = df[(df['date'] < back_cut_off_date) | ((df['date'] == back_cut_off_date) & (df['time'] < rolling_time))]
+                    
                     df_list.append(df)
     
             cols = ['datetime', 'date', 'time', 'open', 'high', 'low', 'close', 'volume', 'expiry_date','RTH']
@@ -272,7 +277,7 @@ class Database:
             df['datetime'] = df['date'] + ' ' + df['time']
             df['datetime'] = pd.to_datetime(df['datetime'], format='%Y%m%d %H%M%S')
             df['RTH'] = df['RTH'].astype(bool)
-
+            
             df = df[cols]
             df = df.set_index(keys='datetime')
             df = df.sort_index(ascending=True)
